==> crm-mybatisdata-1.4.2.8.release.jar: com/biz/crm/sqlupdate/oracle/OracleUserTablesService.java <==
package com.biz.crm.sqlupdate.oracle;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.biz.crm.sqlupdate.CrmColumnVo;
import com.biz.crm.sqlupdate.CrmTableVo;
import com.biz.crm.sqlupdate.IndexVo;
import com.biz.crm.sqlupdate.mapper.DoOracleUpdateSqlMapper;
import com.biz.crm.sqlupdate.oracle.mapper.OracleUserTablesMapper;
import com.biz.crm.sqlupdate.oracle.vo.AllTabColsVo;
import com.biz.crm.sqlupdate.vo.PrimaryKey;
import com.biz.crm.sqlupdate.vo.TableColumnNote;
import com.biz.crm.sqlupdate.vo.TableIndex;
import com.biz.crm.sqlupdate.vo.TableNote;
import com.biz.crm.util.CollectionUtil;
import com.biz.crm.util.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author jianglong
 * @version V1.0
 * @Package com.biz.crm.sqlupdate.oracle
 * @Description: TODO
 * @date 2021/3/16 下午1:25
 */
@Service
public class OracleUserTablesService {
    @Resource
    private OracleUserTablesMapper oracleUserTablesMapper;
    @Resource
    private DoOracleUpdateSqlMapper doOracleUpdateSqlMapper;
    /**
     * 获取所有表
     * @return
     */
    private Map<String,OracleUserTables> getAllTables() {
        Map<String,OracleUserTables> map = new HashMap<>();
        List<OracleUserTables> userTables = oracleUserTablesMapper.selectList(new QueryWrapper<>());
        if(CollectionUtil.listNotEmptyNotSizeZero(userTables)){
            for(OracleUserTables oracleUserTables : userTables){
                String tableName = oracleUserTables.getTableName().toUpperCase();
                map.put(tableName,oracleUserTables);
            }
        }
        return map;
    }
    /**
     * 执行更新
     * @param crmTableVos
     */
    public void updateSql(List<CrmTableVo> crmTableVos){
        if(CollectionUtil.listNotEmptyNotSizeZero(crmTableVos)){
            //所有存在的表
            Map<String,OracleUserTables> mapTable =  getAllTables() ;
            for(CrmTableVo crmTableVo : crmTableVos){
                String tableName = crmTableVo.getName();
                if(mapTable.containsKey(tableName)){
                    updateTable(crmTableVo);
                }else {
                    initTable(crmTableVo);
                }
            }
        }
    }

    /**
     * 新增表
     * 1、创建表
     * 2、创建主键
     * 3、创建索引
     * 4、创建注释
     * 5、更新表注释
     */
    private void initTable(CrmTableVo crmTableVo){
        //1、创建表
        doOracleUpdateSqlMapper.createTable(crmTableVo);
        //2、创建主键
        if (crmTableVo.getKey()!=null){
            doOracleUpdateSqlMapper.updatePrimaryKey(crmTableVo);
        }
        //3、创建索引
        if(CollectionUtil.listNotEmptyNotSizeZero(crmTableVo.getIndexVos())){
            for(IndexVo indexVo : crmTableVo.getIndexVos()){
                doOracleUpdateSqlMapper.updateIndex(indexVo,crmTableVo);
            }
        }
        //4、创建注释
        if(CollectionUtil.listNotEmptyNotSizeZero(crmTableVo.getCrmColumnVos())){
          for(CrmColumnVo crmColumnVo : crmTableVo.getCrmColumnVos() ){
              doOracleUpdateSqlMapper.commentTable(crmColumnVo,crmTableVo.getName());
          }
        }
        updateTableNote(crmTableVo);

    }

    private void updateTableNote(CrmTableVo crmTableVo){
        TableNote oracleTableNote =  doOracleUpdateSqlMapper.getTableNote(crmTableVo.getName());
        if(oracleTableNote!=null&& StringUtils.isNotEmpty(oracleTableNote.getComments())){
          //TODO
        }else {
            if(StringUtils.isNotEmpty(crmTableVo.getTableNote())){
                doOracleUpdateSqlMapper.updateTableNote(crmTableVo);
            }
        }
    }

    /**
     * 修改表
     */
    private void updateTable(CrmTableVo crmTableVo){
        List<AllTabColsVo> tabColsVos =  doOracleUpdateSqlMapper.getAllTab(crmTableVo.getName());
        Map<String,AllTabColsVo> mapCols = new HashMap<>();
        for(AllTabColsVo allTabColsVo : tabColsVos){
           String columnName = allTabColsVo.getColumnName().toUpperCase();
            mapCols.put(columnName,allTabColsVo);
        }
        if(CollectionUtil.listNotEmptyNotSizeZero(crmTableVo.getCrmColumnVos())){
            for(CrmColumnVo crmColumnVo : crmTableVo.getCrmColumnVos()){
              if(mapCols.containsKey(crmColumnVo.getName())){
                  continue;
              }else {
                  //新增字段
                  doOracleUpdateSqlMapper.addCols(crmColumnVo,crmTableVo.getName());
                  //新增注解
                  doOracleUpdateSqlMapper.commentTable(crmColumnVo,crmTableVo.getName());
              }
            }
            //更新主键
            updatePrimaryKeys(crmTableVo);
        }
        //更新表注释
        updateTableNote(crmTableVo);
        //更新列注释
        updateTableColumnNote(crmTableVo);
        //处理索引
        updateIndex(crmTableVo);
    }

    /**
     * 更新主键
     * @param crmTableVo
     */
    private void updatePrimaryKeys(CrmTableVo crmTableVo){
        if(crmTableVo.getKey()==null){
            return;
        }
        //查询所有主键
        List<PrimaryKey> primaryKeys = doOracleUpdateSqlMapper.getPrimaryKey(crmTableVo.getName());
        if(CollectionUtil.listEmpty(primaryKeys)){
            return;
        }
        Map<String, PrimaryKey> map = new HashMap<>();
        for(PrimaryKey item : primaryKeys){
            map.put(item.getColumnName().toUpperCase(),item);
        }
        if(!map.containsKey(crmTableVo.getKey().getName())){
            doOracleUpdateSqlMapper.updatePrimaryKey(crmTableVo);
        }
    }

    /**
     * 更新索引
     * @param crmTableVo
     */
    private void updateIndex(CrmTableVo crmTableVo){
        if(CollectionUtil.listEmpty(crmTableVo.getIndexVos())){
            return;
        }
        List<TableIndex> indexList =   doOracleUpdateSqlMapper.getAllIndex(crmTableVo.getName());
        Map<String, TableIndex> map = new HashMap<>();
        for(TableIndex index :  indexList){
          String columnName = index.getColumnName().toUpperCase();
          if(crmTableVo.getKey()!=null&&crmTableVo.getKey().getName().equals(columnName)){
              continue;
          }
            map.put(index.getIndexName().toUpperCase(),index);
        }
        for(IndexVo indexVo : crmTableVo.getIndexVos()){
            if(map.containsKey(indexVo.getName())){
                continue;
            }
            doOracleUpdateSqlMapper.updateIndex(indexVo,crmTableVo);
        }
    }

    /**
     * 更新列注释
     */
    private void updateTableColumnNote(CrmTableVo crmTableVo){
        List<TableColumnNote> columnNotes =  doOracleUpdateSqlMapper.getColumnNote(crmTableVo.getName());
        if(CollectionUtil.listEmpty(columnNotes)){
            return;
        }
        Map<String,TableColumnNote> map = new HashMap<>();
        for(TableColumnNote note : columnNotes){
            map.put(note.getColumnName().toUpperCase(),note);
        }
        for(CrmColumnVo crmColumnVo : crmTableVo.getCrmColumnVos()){
            //字段不存在或者 现有表字段未写注释 但是本次字段有注释
            if(StringUtils.isEmpty(crmColumnVo.getNote())){
                continue;
            }
            if(!map.containsKey(crmColumnVo.getName())||StringUtils.isEmpty(map.get(crmColumnVo.getName()).getNote())){
                doOracleUpdateSqlMapper.commentTable(crmColumnVo,crmTableVo.getName());
            }
        }
    }

}

==> crm-mybatisdata-1.4.3.0.release.jar: com/biz/crm/sqlupdate/oracle/OracleUserTablesService.java <==
package com.biz.crm.sqlupdate.oracle;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.biz.crm.sqlupdate.CrmColumnVo;
import com.biz.crm.sqlupdate.CrmTableVo;
import com.biz.crm.sqlupdate.IndexVo;
import com.biz.crm.sqlupdate.mapper.DoOracleUpdateSqlMapper;
import com.biz.crm.sqlupdate.oracle.mapper.OracleUserTablesMapper;
import com.biz.crm.sqlupdate.oracle.vo.AllTabColsVo;
import com.biz.crm.sqlupdate.vo.PrimaryKey;
import com.biz.crm.sqlupdate.vo.TableColumnNote;
import com.biz.crm.sqlupdate.vo.TableIndex;
import com.biz.crm.sqlupdate.vo.TableNote;
import com.biz.crm.util.CollectionUtil;
import com.biz.crm.util.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author jianglong
 * @version V1.0
 * @Package com.biz.crm.sqlupdate.oracle
 * @Description: TODO
 * @date 2021/3/16 下午1:25
 */
@Service
public class OracleUserTablesService {
    @Autowired(required = false)
    private OracleUserTablesMapper oracleUserTablesMapper;
    @Autowired(required = false)
    private DoOracleUpdateSqlMapper doOracleUpdateSqlMapper;
    /**
     * 获取所有表
     * @return
     */
    private Map<String,OracleUserTables> getAllTables() {
        Map<String,OracleUserTables> map = new HashMap<>();
        List<OracleUserTables> userTables = oracleUserTablesMapper.selectList(new QueryWrapper<>());
        if(CollectionUtil.listNotEmptyNotSizeZero(userTables)){
            for(OracleUserTables oracleUserTables : userTables){
                String tableName = oracleUserTables.getTableName().toUpperCase();
                map.put(tableName,oracleUserTables);
            }
        }
        return map;
    }
    /**
     * 执行更新
     * @param crmTableVos
     */
    public void updateSql(List<CrmTableVo> crmTableVos){
        if(CollectionUtil.listNotEmptyNotSizeZero(crmTableVos)){
            //所有存在的表
            Map<String,OracleUserTables> mapTable =  getAllTables() ;
            for(CrmTableVo crmTableVo : crmTableVos){
                String tableName = crmTableVo.getName();
                if(mapTable.containsKey(tableName)){
                    updateTable(crmTableVo);
                }else {
                    initTable(crmTableVo);
                }
            }
        }
    }

    /**
     * 新增表
     * 1、创建表
     * 2、创建主键
     * 3、创建索引
     * 4、创建注释
     * 5、更新表注释
     */
    private void initTable(CrmTableVo crmTableVo){
        //1、创建表
        doOracleUpdateSqlMapper.createTable(crmTableVo);
        //2、创建主键
        if (crmTableVo.getKey()!=null){
            doOracleUpdateSqlMapper.updatePrimaryKey(crmTableVo);
        }
        //3、创建索引
        if(CollectionUtil.listNotEmptyNotSizeZero(crmTableVo.getIndexVos())){
            for(IndexVo indexVo : crmTableVo.getIndexVos()){
                doOracleUpdateSqlMapper.updateIndex(indexVo,crmTableVo);
            }
        }
        //4、创建注释
        if(CollectionUtil.listNotEmptyNotSizeZero(crmTableVo.getCrmColumnVos())){
          for(CrmColumnVo crmColumnVo : crmTableVo.getCrmColumnVos() ){
              doOracleUpdateSqlMapper.commentTable(crmColumnVo,crmTableVo.getName());
          }
        }
        updateTableNote(crmTableVo);

    }

    private void updateTableNote(CrmTableVo crmTableVo){
        TableNote oracleTableNote =  doOracleUpdateSqlMapper.getTableNote(crmTableVo.getName());
        if(oracleTableNote!=null&& StringUtils.isNotEmpty(oracleTableNote.getComments())){
          //TODO
        }else {
            if(StringUtils.isNotEmpty(crmTableVo.getTableNote())){
                doOracleUpdateSqlMapper.updateTableNote(crmTableVo);
            }
        }
    }

    /**
     * 修改表
     */
    private void updateTable(CrmTableVo crmTableVo){
        List<AllTabColsVo> tabColsVos =  doOracleUpdateSqlMapper.getAllTab(crmTableVo.getName());
        Map<String,AllTabColsVo> mapCols = new HashMap<>();
        for(AllTabColsVo allTabColsVo : tabColsVos){
           String columnName = allTabColsVo.getColumnName().toUpperCase();
            mapCols.put(columnName,allTabColsVo);
        }
        if(CollectionUtil.listNotEmptyNotSizeZero(crmTableVo.getCrmColumnVos())){
            for(CrmColumnVo crmColumnVo : crmTableVo.getCrmColumnVos()){
              if(mapCols.containsKey(crmColumnVo.getName())){
                  continue;
              }else {
                  //新增字段
                  doOracleUpdateSqlMapper.addCols(crmColumnVo,crmTableVo.getName());
                  //新增注解
                  doOracleUpdateSqlMapper.commentTable(crmColumnVo,crmTableVo.getName());
              }
            }
            //更新主键
            updatePrimaryKeys(crmTableVo);
        }
        //更新表注释
        updateTableNote(crmTableVo);
        //更新列注释
        updateTableColumnNote(crmTableVo);
        //处理索引
        updateIndex(crmTableVo);
    }

    /**
     * 更新主键
     * @param crmTableVo
     */
    private void updatePrimaryKeys(CrmTableVo crmTableVo){
        if(crmTableVo.getKey()==null){
            return;
        }
        //查询所有主键
        List<PrimaryKey> primaryKeys = doOracleUpdateSqlMapper.getPrimaryKey(crmTableVo.getName());
        if(CollectionUtil.listEmpty(primaryKeys)){
            return;
        }
        Map<String, PrimaryKey> map = new HashMap<>();
        for(PrimaryKey item : primaryKeys){
            map.put(item.getColumnName().toUpperCase(),item);
        }
        if(!map.containsKey(crmTableVo.getKey().getName())){
            doOracleUpdateSqlMapper.updatePrimaryKey(crmTableVo);
        }
    }

    /**
     * 更新索引
     * @param crmTableVo
     */
    private void updateIndex(CrmTableVo crmTableVo){
        if(CollectionUtil.listEmpty(crmTableVo.getIndexVos())){
            return;
        }
        List<TableIndex> indexList =   doOracleUpdateSqlMapper.getAllIndex(crmTableVo.getName());
        Map<String, TableIndex> map = new HashMap<>();
        for(TableIndex index :  indexList){
          String columnName = index.getColumnName().toUpperCase();
          if(crmTableVo.getKey()!=null&&crmTableVo.getKey().getName().equals(columnName)){
              continue;
          }
            map.put(index.getIndexName().toUpperCase(),index);
        }
        for(IndexVo indexVo : crmTableVo.getIndexVos()){
            if(map.containsKey(indexVo.getName())){
                continue;
            }
            doOracleUpdateSqlMapper.updateIndex(indexVo,crmTableVo);
        }
    }

    /**
     * 更新列注释
     */
    private void updateTableColumnNote(CrmTableVo crmTableVo){
        List<TableColumnNote> columnNotes =  doOracleUpdateSqlMapper.getColumnNote(crmTableVo.getName());
        if(CollectionUtil.listEmpty(columnNotes)){
            return;
        }
        Map<String,TableColumnNote> map = new HashMap<>();
        for(TableColumnNote note : columnNotes){
            map.put(note.getColumnName().toUpperCase(),note);
        }
        for(CrmColumnVo crmColumnVo : crmTableVo.getCrmColumnVos()){
            //字段不存在或者 现有表字段未写注释 但是本次字段有注释
            if(StringUtils.isEmpty(crmColumnVo.getNote())){
                continue;
            }
            if(!map.containsKey(crmColumnVo.getName())||StringUtils.isEmpty(map.get(crmColumnVo.getName()).getNote())){
                doOracleUpdateSqlMapper.commentTable(crmColumnVo,crmTableVo.getName());
            }
        }
    }

}
